@@ -4,6 +4,7 @@
 #' @param regionvalue vector with the values that you want to plot in percentiles in the Spain map.
 #' @param main the specific title of the map plot
 #' @param name the assigned name for the legend in map plot.
+#' @param bigred if the user wants red color for bigger values in the regions `bigred` == `'TRUE'` (default value). However if the user wants to modify the colors and assign red to lower values `bigred` == `'FALSE'`.
 #'
 #' @return a map from the regions of Spain colored with the variable provided by the user.
 #'
@@ -30,7 +31,7 @@
 #' SpainMap(regionvalue, main, name)
 #'
 #' @export
-SpainMap <- function(regionvalue, main, name){
+SpainMap <- function(regionvalue, main, name, bigred = TRUE){
 
   if(length(regionvalue) != 17){
     stop("The regionvalue is not a vector of length 17.")
@@ -42,23 +43,20 @@ SpainMap <- function(regionvalue, main, name){
   sf::st_crs(autonomias) <- 32630
   autonomias <- st_transform(autonomias, crs = 32630)
 
-  #if (is.na(st_crs(autonomias))) {
-  #  st_crs(autonomias) <- 32630
-  #} else {
-  #  # Si ya tiene un CRS asignado, y no es el correcto, cambiar a 32630
-  #  if (st_crs(autonomias)$epsg != 32630) {
-  #    autonomias <- st_transform(autonomias, crs = 32630)
-  #  }
-  #}
+  if(bigred == TRUE){
+    cols <- c("#FFFFAF", "#FFD800", "#FF9D00", "#FF0000")
+  }else if(bigred == FALSE){
+    cols <- c("#FF0000", "#FF9D00", "#FFD800", "#FFFFAF")
+  }
 
   tm_shape(autonomias) +
-    tm_polygons(col=name, palette = c("#FF0000", "#FF9D00", "#FFD800", "#FFFFAF"),
+    tm_polygons(col=name, palette = cols,
                   breaks=quantile(autonomias[[5]]), border.col = "black",
                   title = name) +
     tm_layout(main,
                 legend.title.fontfamily = "serif",
                 legend.title.size = 1.3,
-                legend.text.size = 0.6,
+                legend.text.size = 0.9,
                 legend.width = 0.4) +
     tm_shape(autonomias) +
     tm_borders(lwd = 1)
